==> infima_client-0.59.0-py3-none-any.whl: infima_client/cohort.py <==
from typing import Dict, List, Optional, Union

import infima_client.api.cohort_service.cohort_service_get_cohort_summary as cohort_service_get_cohort_summary
import infima_client.api.cohort_service.cohort_service_get_coverage_summary as cohort_service_get_coverage_summary
import infima_client.api.cohort_service.cohort_service_get_historical_prepayments as cohort_service_get_historical_prepayments
import infima_client.api.cohort_service.cohort_service_get_pool_components as cohort_service_get_pool_components
from infima_client.models import *

from .client import Client
from .types import UNSET, Response, Unset


class cohort:
    def __init__(self, client: Client):
        self.client = client
        self._detailed = cohortDetailed(client)

    def get_cohort_summary(
        self,
        cohort: Union[Unset, str] = UNSET,
        dateyear: Union[Unset, int] = UNSET,
        datemonth: Union[Unset, int] = UNSET,
        dateday: Union[Unset, int] = UNSET,
    ) -> Optional[
        Union[
            CohortSummary,
            CohortSummaryUnauthorized,
            CohortSummaryNotFound,
            CohortSummaryError,
        ]
    ]:

        """


        Args:
            cohort: None
            dateyear: Year of the date. Must be from 1 to 9999, or 0 to specify a date without a year
            datemonth: Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
            dateday: Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to specify a year by itself or a year and month where the day isn't significant.Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return cohort_service_get_cohort_summary.sync(
            client=self.client,
            cohort=cohort,
            dateyear=dateyear,
            datemonth=datemonth,
            dateday=dateday,
        )

    def get_coverage_summary(
        self,
        year: Union[Unset, int] = UNSET,
        month: Union[Unset, int] = UNSET,
        day: Union[Unset, int] = UNSET,
    ) -> Optional[
        Union[
            CohortCoverage,
            CohortCoverageUnauthorized,
            CohortCoverageNotFound,
            CohortCoverageError,
        ]
    ]:

        """


        Args:
            year: Year of the date. Must be from 1 to 9999, or 0 to specify a date without a year
            month: Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
            day: Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to specify a year by itself or a year and month where the day isn't significant.Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return cohort_service_get_coverage_summary.sync(
            client=self.client, year=year, month=month, day=day
        )

    def get_historical_prepayments(
        self,
        cohort: str,
        dateyear: Union[Unset, int] = UNSET,
        datemonth: Union[Unset, int] = UNSET,
        dateday: Union[Unset, int] = UNSET,
        num_months: Union[Unset, int] = UNSET,
    ) -> Optional[
        Union[
            CohortHistoricalPrepayments,
            CohortHistoricalPrepaymentsUnauthorized,
            CohortHistoricalPrepaymentsNotFound,
            CohortHistoricalPrepaymentsError,
        ]
    ]:

        """


        Args:
            cohort: Cohort to fetch.
            dateyear: Year of the date. Must be from 1 to 9999, or 0 to specify a date without a year
            datemonth: Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
            dateday: Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to specify a year by itself or a year and month where the day isn't significant.Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
            num_months: None

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return cohort_service_get_historical_prepayments.sync(
            client=self.client,
            cohort=cohort,
            dateyear=dateyear,
            datemonth=datemonth,
            dateday=dateday,
            num_months=num_months,
        )

    def get_pool_components(
        self, cohort: str
    ) -> Optional[
        Union[
            CohortPoolComponents,
            CohortPoolComponentsUnauthorized,
            CohortPoolComponentsNotFound,
            CohortPoolComponentsError,
        ]
    ]:

        """


        Args:
            cohort: Cohort we want to fetch pool components for.

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return cohort_service_get_pool_components.sync(
            client=self.client, cohort=cohort
        )


class cohortDetailed:
    def __init__(self, client: Client):
        self.client = client

    def get_cohort_summary(
        self,
        cohort: Union[Unset, str] = UNSET,
        dateyear: Union[Unset, int] = UNSET,
        datemonth: Union[Unset, int] = UNSET,
        dateday: Union[Unset, int] = UNSET,
    ) -> Response[
        Union[
            CohortSummary,
            CohortSummaryUnauthorized,
            CohortSummaryNotFound,
            CohortSummaryError,
        ]
    ]:

        return cohort_service_get_cohort_summary.sync_detailed(
            client=self.client,
            cohort=cohort,
            dateyear=dateyear,
            datemonth=datemonth,
            dateday=dateday,
        )

    def get_coverage_summary(
        self,
        year: Union[Unset, int] = UNSET,
        month: Union[Unset, int] = UNSET,
        day: Union[Unset, int] = UNSET,
    ) -> Response[
        Union[
            CohortCoverage,
            CohortCoverageUnauthorized,
            CohortCoverageNotFound,
            CohortCoverageError,
        ]
    ]:

        return cohort_service_get_coverage_summary.sync_detailed(
            client=self.client, year=year, month=month, day=day
        )

    def get_historical_prepayments(
        self,
        cohort: str,
        dateyear: Union[Unset, int] = UNSET,
        datemonth: Union[Unset, int] = UNSET,
        dateday: Union[Unset, int] = UNSET,
        num_months: Union[Unset, int] = UNSET,
    ) -> Response[
        Union[
            CohortHistoricalPrepayments,
            CohortHistoricalPrepaymentsUnauthorized,
            CohortHistoricalPrepaymentsNotFound,
            CohortHistoricalPrepaymentsError,
        ]
    ]:

        return cohort_service_get_historical_prepayments.sync_detailed(
            client=self.client,
            cohort=cohort,
            dateyear=dateyear,
            datemonth=datemonth,
            dateday=dateday,
            num_months=num_months,
        )

    def get_pool_components(
        self, cohort: str
    ) -> Response[
        Union[
            CohortPoolComponents,
            CohortPoolComponentsUnauthorized,
            CohortPoolComponentsNotFound,
            CohortPoolComponentsError,
        ]
    ]:

        return cohort_service_get_pool_components.sync_detailed(
            client=self.client, cohort=cohort
        )

==> infima_client-0.102.0-py3-none-any.whl: infima_client/cohort.py <==
from typing import Dict, List, Optional, Union

import infima_client.api.cohort_service.cohort_service_get_cohort_associations as cohort_service_get_cohort_associations
import infima_client.api.cohort_service.cohort_service_get_cohort_summary as cohort_service_get_cohort_summary
import infima_client.api.cohort_service.cohort_service_get_coverage_summary as cohort_service_get_coverage_summary
import infima_client.api.cohort_service.cohort_service_get_historical_prepayments as cohort_service_get_historical_prepayments
import infima_client.api.cohort_service.cohort_service_get_pool_associations as cohort_service_get_pool_associations
import infima_client.api.cohort_service.cohort_service_get_pool_components as cohort_service_get_pool_components
import infima_client.api.cohort_service.cohort_service_search_cohort as cohort_service_search_cohort
from infima_client.models import *

from .client import Client
from .types import UNSET, Response, Unset


class cohort:
    def __init__(self, client: Client):
        self.client = client
        self._detailed = cohortDetailed(client)

    def get_cohort_associations(
        self,
        cohort: Union[Unset, str] = UNSET,
        dateyear: Union[Unset, int] = UNSET,
        datemonth: Union[Unset, int] = UNSET,
        dateday: Union[Unset, int] = UNSET,
        month_back: Union[Unset, int] = UNSET,
    ) -> Optional[
        Union[
            CohortAssociations,
            CohortAssociationsUnauthorized,
            CohortAssociationsNotFound,
            CohortAssociationsError,
        ]
    ]:

        """


        Args:
            cohort: None
            dateyear: Year of the date. Must be from 1 to 9999, or 0 to specify a date without a year
            datemonth: Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
            dateday: Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to specify a year by itself or a year and month where the day isn't significant.Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
            month_back: None

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return cohort_service_get_cohort_associations.sync(
            client=self.client,
            cohort=cohort,
            dateyear=dateyear,
            datemonth=datemonth,
            dateday=dateday,
            month_back=month_back,
        )

    def get_cohort_summary(
        self,
        cohort: Union[Unset, str] = UNSET,
        dateyear: Union[Unset, int] = UNSET,
        datemonth: Union[Unset, int] = UNSET,
        dateday: Union[Unset, int] = UNSET,
    ) -> Optional[
        Union[
            CohortSummary,
            CohortSummaryUnauthorized,
            CohortSummaryNotFound,
            CohortSummaryError,
        ]
    ]:

        """


        Args:
            cohort: None
            dateyear: Year of the date. Must be from 1 to 9999, or 0 to specify a date without a year
            datemonth: Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
            dateday: Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to specify a year by itself or a year and month where the day isn't significant.Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return cohort_service_get_cohort_summary.sync(
            client=self.client,
            cohort=cohort,
            dateyear=dateyear,
            datemonth=datemonth,
            dateday=dateday,
        )

    def get_coverage_summary(
        self,
        dateyear: Union[Unset, int] = UNSET,
        datemonth: Union[Unset, int] = UNSET,
        dateday: Union[Unset, int] = UNSET,
        month_back: Union[Unset, int] = UNSET,
    ) -> Optional[
        Union[
            CohortCoverage,
            CohortCoverageUnauthorized,
            CohortCoverageNotFound,
            CohortCoverageError,
        ]
    ]:

        """


        Args:
            dateyear: Year of the date. Must be from 1 to 9999, or 0 to specify a date without a year
            datemonth: Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
            dateday: Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to specify a year by itself or a year and month where the day isn't significant.Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
            month_back: None

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return cohort_service_get_coverage_summary.sync(
            client=self.client,
            dateyear=dateyear,
            datemonth=datemonth,
            dateday=dateday,
            month_back=month_back,
        )

    def get_historical_prepayments(
        self,
        cohort: str,
        periodyear: Union[Unset, int] = UNSET,
        periodmonth: Union[Unset, int] = UNSET,
        convention: Union[
            Unset, CohortService_GetHistoricalPrepaymentsConvention
        ] = CohortService_GetHistoricalPrepaymentsConvention.PERIOD,
        num_months: Union[Unset, int] = UNSET,
    ) -> Optional[
        Union[
            CohortHistoricalPrepayments,
            CohortHistoricalPrepaymentsUnauthorized,
            CohortHistoricalPrepaymentsNotFound,
            CohortHistoricalPrepaymentsError,
        ]
    ]:

        """


        Args:
            cohort: Cohort to fetch.
            periodyear: Year of the period. Must be from 1 to 9999, or 0 to specify a date without a year
            periodmonth: Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
            convention: Convention to use for the date, can be PERIOD or FACTOR_DATE.
            num_months: None

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return cohort_service_get_historical_prepayments.sync(
            client=self.client,
            cohort=cohort,
            periodyear=periodyear,
            periodmonth=periodmonth,
            convention=convention,
            num_months=num_months,
        )

    def get_pool_associations(
        self,
        cusip: Union[Unset, str] = UNSET,
        dateyear: Union[Unset, int] = UNSET,
        datemonth: Union[Unset, int] = UNSET,
        dateday: Union[Unset, int] = UNSET,
        month_back: Union[Unset, int] = UNSET,
    ) -> Optional[
        Union[
            PoolAssociations,
            PoolAssociationsUnauthorized,
            PoolAssociationsNotFound,
            PoolAssociationsError,
        ]
    ]:

        """


        Args:
            cusip: None
            dateyear: Year of the date. Must be from 1 to 9999, or 0 to specify a date without a year
            datemonth: Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
            dateday: Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to specify a year by itself or a year and month where the day isn't significant.Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
            month_back: None

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return cohort_service_get_pool_associations.sync(
            client=self.client,
            cusip=cusip,
            dateyear=dateyear,
            datemonth=datemonth,
            dateday=dateday,
            month_back=month_back,
        )

    def get_pool_components(
        self, cohort: str
    ) -> Optional[
        Union[
            CohortPoolComponents,
            CohortPoolComponentsUnauthorized,
            CohortPoolComponentsNotFound,
            CohortPoolComponentsError,
        ]
    ]:

        """


        Args:
            cohort: Cohort we want to fetch pool components for.

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return cohort_service_get_pool_components.sync(
            client=self.client, cohort=cohort
        )

    def search_cohort(
        self,
        ticker: Union[Unset, str] = UNSET,
        coupon: Union[Unset, float] = UNSET,
        vintage: Union[Unset, int] = UNSET,
        type: Union[Unset, str] = UNSET,
    ) -> Optional[
        Union[
            CohortSearch,
            CohortSearchUnauthorized,
            CohortSearchNotFound,
            CohortSearchError,
        ]
    ]:

        """


        Args:
            ticker: None
            coupon: None
            vintage: None
            type: None

        Returns:
            Either a valid response or an unauthorized, not found or other error.
        """

        return cohort_service_search_cohort.sync(
            client=self.client, ticker=ticker, coupon=coupon, vintage=vintage, type=type
        )


class cohortDetailed:
    def __init__(self, client: Client):
        self.client = client

    def get_cohort_associations(
        self,
        cohort: Union[Unset, str] = UNSET,
        dateyear: Union[Unset, int] = UNSET,
        datemonth: Union[Unset, int] = UNSET,
        dateday: Union[Unset, int] = UNSET,
        month_back: Union[Unset, int] = UNSET,
    ) -> Response[
        Union[
            CohortAssociations,
            CohortAssociationsUnauthorized,
            CohortAssociationsNotFound,
            CohortAssociationsError,
        ]
    ]:

        return cohort_service_get_cohort_associations.sync_detailed(
            client=self.client,
            cohort=cohort,
            dateyear=dateyear,
            datemonth=datemonth,
            dateday=dateday,
            month_back=month_back,
        )

    def get_cohort_summary(
        self,
        cohort: Union[Unset, str] = UNSET,
        dateyear: Union[Unset, int] = UNSET,
        datemonth: Union[Unset, int] = UNSET,
        dateday: Union[Unset, int] = UNSET,
    ) -> Response[
        Union[
            CohortSummary,
            CohortSummaryUnauthorized,
            CohortSummaryNotFound,
            CohortSummaryError,
        ]
    ]:

        return cohort_service_get_cohort_summary.sync_detailed(
            client=self.client,
            cohort=cohort,
            dateyear=dateyear,
            datemonth=datemonth,
            dateday=dateday,
        )

    def get_coverage_summary(
        self,
        dateyear: Union[Unset, int] = UNSET,
        datemonth: Union[Unset, int] = UNSET,
        dateday: Union[Unset, int] = UNSET,
        month_back: Union[Unset, int] = UNSET,
    ) -> Response[
        Union[
            CohortCoverage,
            CohortCoverageUnauthorized,
            CohortCoverageNotFound,
            CohortCoverageError,
        ]
    ]:

        return cohort_service_get_coverage_summary.sync_detailed(
            client=self.client,
            dateyear=dateyear,
            datemonth=datemonth,
            dateday=dateday,
            month_back=month_back,
        )

    def get_historical_prepayments(
        self,
        cohort: str,
        periodyear: Union[Unset, int] = UNSET,
        periodmonth: Union[Unset, int] = UNSET,
        convention: Union[
            Unset, CohortService_GetHistoricalPrepaymentsConvention
        ] = CohortService_GetHistoricalPrepaymentsConvention.PERIOD,
        num_months: Union[Unset, int] = UNSET,
    ) -> Response[
        Union[
            CohortHistoricalPrepayments,
            CohortHistoricalPrepaymentsUnauthorized,
            CohortHistoricalPrepaymentsNotFound,
            CohortHistoricalPrepaymentsError,
        ]
    ]:

        return cohort_service_get_historical_prepayments.sync_detailed(
            client=self.client,
            cohort=cohort,
            periodyear=periodyear,
            periodmonth=periodmonth,
            convention=convention,
            num_months=num_months,
        )

    def get_pool_associations(
        self,
        cusip: Union[Unset, str] = UNSET,
        dateyear: Union[Unset, int] = UNSET,
        datemonth: Union[Unset, int] = UNSET,
        dateday: Union[Unset, int] = UNSET,
        month_back: Union[Unset, int] = UNSET,
    ) -> Response[
        Union[
            PoolAssociations,
            PoolAssociationsUnauthorized,
            PoolAssociationsNotFound,
            PoolAssociationsError,
        ]
    ]:

        return cohort_service_get_pool_associations.sync_detailed(
            client=self.client,
            cusip=cusip,
            dateyear=dateyear,
            datemonth=datemonth,
            dateday=dateday,
            month_back=month_back,
        )

    def get_pool_components(
        self, cohort: str
    ) -> Response[
        Union[
            CohortPoolComponents,
            CohortPoolComponentsUnauthorized,
            CohortPoolComponentsNotFound,
            CohortPoolComponentsError,
        ]
    ]:

        return cohort_service_get_pool_components.sync_detailed(
            client=self.client, cohort=cohort
        )

    def search_cohort(
        self,
        ticker: Union[Unset, str] = UNSET,
        coupon: Union[Unset, float] = UNSET,
        vintage: Union[Unset, int] = UNSET,
        type: Union[Unset, str] = UNSET,
    ) -> Response[
        Union[
            CohortSearch,
            CohortSearchUnauthorized,
            CohortSearchNotFound,
            CohortSearchError,
        ]
    ]:

        return cohort_service_search_cohort.sync_detailed(
            client=self.client, ticker=ticker, coupon=coupon, vintage=vintage, type=type
        )
